==> create-node-react-app-1.0.26.tgz: package/lib-esm/files/src/index.tsx <==
import React from 'react'
import ReactDOM from 'react-dom'
/* IF auth:firebase */ import './config/firebase'
/* IF i18n:true */ import './config/i18next'
/* IF gql:true */ import { ApolloProvider } from '@apollo/client'
/* IF gql:true */ import { createApolloClient } from './config/createApolloClient'
import providers, { Provide } from 'react-manage-providers'
/* IF mui:true */ import { ThemeProvider, CssBaseline, Theme } from '@mui/material'
/* IF mui:true */ import theme from './config/createMuiTheme'
/* IF router:true */ import { BrowserRouter as Router, Route, Switch } from 'react-router-dom'
import reportWebVitals from './reportWebVitals'
import App from './App'

// IF gql:true
// initialize apollo client
const client = createApolloClient(() => 'bearer_token')
providers.push(ApolloProvider, { client })
// ENDIF

// IF mui:true
// initialize MUI theme
const MuiThemeProvider = ({ theme, children }: React.PropsWithChildren<{ theme: Theme }>) => <ThemeProvider theme={theme}>
  <CssBaseline />
  {children}
</ThemeProvider>
providers.push(MuiThemeProvider, { theme })
// ENDIF

// IF router:true
function AppRoutes() {
  return <Switch>
    <Route>hello</Route>
  </Switch>
}
// ENDIF

// Render app
ReactDOM.render(
  <React.StrictMode>
    <Provide>
      {/* IF router:true */}
      <Router>
        <App>
          <AppRoutes />
        </App>
      </Router>
      {/* ENDIF */}
      {/* IF router:false */}
      <App />
      {/* ENDIF */}
    </Provide>
  </React.StrictMode>,
  document.getElementById('root')
)

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals()

==> create-node-react-app-1.0.27.tgz: package/lib-esm/files/src/index.tsx <==
import React from 'react'
import ReactDOM from 'react-dom'
/* IF gql:true,auth:firebase */ import { getAuth } from 'firebase/auth'
/* IF auth:firebase */ import './config/firebase'
/* IF i18n:true */ import './config/i18next'
/* IF gql:true */ import { ApolloProvider } from '@apollo/client'
/* IF gql:true */ import { createApolloClient } from './config/createApolloClient'
import providers, { Provide } from 'react-manage-providers'
/* IF mui:true */ import { ThemeProvider, CssBaseline, Theme } from '@mui/material'
/* IF mui:true */ import theme from './config/createMuiTheme'
/* IF router:true */ import { BrowserRouter as Router, Route, Switch } from 'react-router-dom'
import reportWebVitals from './reportWebVitals'
import App from './App'
/* IF router:true */ import { Home, SignUp } from './pages'

// IF gql:true,auth:firebase
// initialize apollo client
const client = createApolloClient(() => getAuth().currentUser?.getIdToken())
providers.push(ApolloProvider, { client })
// ENDIF

// IF gql:true,auth:jwt
// initialize apollo client
const client = createApolloClient(() => localStorage.getItem('AUTH_TOKEN') || undefined)
providers.push(ApolloProvider, { client })
// ENDIF

// IF mui:true
// initialize MUI theme
const MuiThemeProvider = ({ theme, children }: React.PropsWithChildren<{ theme: Theme }>) => <ThemeProvider theme={theme}>
  <CssBaseline />
  {children}
</ThemeProvider>
providers.push(MuiThemeProvider, { theme })
// ENDIF

// IF router:true
function AppRoutes() {
  return <Switch>
    <Route path="/signup" component={SignUp} />
    <Route component={Home} />
  </Switch>
}
// ENDIF

// Render app
ReactDOM.render(
  <React.StrictMode>
    <Provide>
      {/* IF router:true */}
      <Router>
        <App>
          <AppRoutes />
        </App>
      </Router>
      {/* ENDIF */}
      {/* IF router:false */}
      <App />
      {/* ENDIF */}
    </Provide>
  </React.StrictMode>,
  document.getElementById('root')
)

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals()
